==> jc-1.4.0.tar.gz: soot/util/StringNumberer.h <==
// public class soot.util.StringNumberer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f5f751433138bc27 soot_util_Numberer
// @dep_class 408144341dbf70b7 soot_util_StringNumberer

// header file dependencies
// @dep_header soot_util_Numberer

#include "soot/util/Numberer.h"

#ifndef _JC_soot_util_StringNumberer_H_
#define _JC_soot_util_StringNumberer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_util_NumberedString$object;

// Typedefs
typedef struct _jc_soot_util_StringNumberer$sub_refs	_jc_soot_util_StringNumberer$sub_refs;
typedef struct _jc_soot_util_StringNumberer$sub_nonrefs	_jc_soot_util_StringNumberer$sub_nonrefs;
typedef struct _jc_soot_util_StringNumberer$refs	_jc_soot_util_StringNumberer$refs;
typedef struct _jc_soot_util_StringNumberer$nonrefs	_jc_soot_util_StringNumberer$nonrefs;
typedef struct _jc_soot_util_StringNumberer$object	_jc_soot_util_StringNumberer$object;

typedef const struct _jc_soot_util_StringNumberer$vmethods	_jc_soot_util_StringNumberer$vmethods;
typedef const struct _jc_soot_util_StringNumberer$vtable	_jc_soot_util_StringNumberer$vtable;
typedef const struct _jc_soot_util_StringNumberer$vtype	_jc_soot_util_StringNumberer$vtype;

// Constructors
extern void _jc_soot_util_StringNumberer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_StringNumberer$object *);

// Virtual methods
extern struct _jc_soot_util_NumberedString$object *_jc_soot_util_StringNumberer$method$find$2cd6887c6a23d922(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *);
extern struct _jc_soot_util_NumberedString$object *_jc_soot_util_StringNumberer$method$findOrAdd$71319f78e7d248ba(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_StringNumberer$method_info$find$2cd6887c6a23d922;
extern _jc_method _jc_soot_util_StringNumberer$method_info$findOrAdd$71319f78e7d248ba;

// Virtual methods structure
struct _jc_soot_util_StringNumberer$vmethods {
	struct _jc_soot_util_NumberedString$object	*(*find$2cd6887c6a23d922)(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *);
	struct _jc_soot_util_NumberedString$object	*(*findOrAdd$71319f78e7d248ba)(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_util_StringNumberer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Numberer$vmethods	soot_util_Numberer;
	_jc_soot_util_StringNumberer$vmethods	soot_util_StringNumberer;
};

// Vtype
struct _jc_soot_util_StringNumberer$vtype {
	_jc_type			type;
	_jc_soot_util_StringNumberer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_StringNumberer$sub_refs {
	struct _jc_java_util_HashMap$object	*stringToNumbered;
};

// Reference instance fields (object)
struct _jc_soot_util_StringNumberer$refs {
    _jc_soot_util_StringNumberer$sub_refs	soot_util_StringNumberer;
    _jc_soot_util_Numberer$sub_refs	soot_util_Numberer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_StringNumberer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_StringNumberer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Numberer$sub_nonrefs	soot_util_Numberer;
    _jc_soot_util_StringNumberer$sub_nonrefs	soot_util_StringNumberer;
};

// Object instance structure
struct _jc_soot_util_StringNumberer$object {
	_jc_soot_util_StringNumberer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_StringNumberer$vtype	*vtype;
	_jc_soot_util_StringNumberer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_StringNumberer$vtype _jc_soot_util_StringNumberer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_StringNumberer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_StringNumberer$class_object;

#endif	/* _JC_soot_util_StringNumberer_H_ */

==> jc-1.4.6.tar.gz: soot/util/StringNumberer.h <==
// public class soot.util.StringNumberer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f5f751433138bc27 soot_util_Numberer
// @dep_class 408144341dbf70b7 soot_util_StringNumberer

// header file dependencies
// @dep_header soot_util_Numberer

#include "soot/util/Numberer.h"

#ifndef _JC_soot_util_StringNumberer_H_
#define _JC_soot_util_StringNumberer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_util_NumberedString$object;

// Typedefs
typedef struct _jc_soot_util_StringNumberer$sub_refs	_jc_soot_util_StringNumberer$sub_refs;
typedef struct _jc_soot_util_StringNumberer$sub_nonrefs	_jc_soot_util_StringNumberer$sub_nonrefs;
typedef struct _jc_soot_util_StringNumberer$refs	_jc_soot_util_StringNumberer$refs;
typedef struct _jc_soot_util_StringNumberer$nonrefs	_jc_soot_util_StringNumberer$nonrefs;
typedef struct _jc_soot_util_StringNumberer$object	_jc_soot_util_StringNumberer$object;

typedef const struct _jc_soot_util_StringNumberer$vmethods	_jc_soot_util_StringNumberer$vmethods;
typedef const struct _jc_soot_util_StringNumberer$vtable	_jc_soot_util_StringNumberer$vtable;
typedef const struct _jc_soot_util_StringNumberer$vtype	_jc_soot_util_StringNumberer$vtype;

// Constructors
extern void _jc_soot_util_StringNumberer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_StringNumberer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_util_NumberedString$object *_jc_soot_util_StringNumberer$method$find$2cd6887c6a23d922(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_NumberedString$object *_jc_soot_util_StringNumberer$method$findOrAdd$71319f78e7d248ba(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_StringNumberer$method_info$find$2cd6887c6a23d922;
extern _jc_method _jc_soot_util_StringNumberer$method_info$findOrAdd$71319f78e7d248ba;

// Virtual methods structure
struct _jc_soot_util_StringNumberer$vmethods {
	struct _jc_soot_util_NumberedString$object	*(*find$2cd6887c6a23d922)(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_NumberedString$object	*(*findOrAdd$71319f78e7d248ba)(_jc_env *, struct _jc_soot_util_StringNumberer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_StringNumberer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Numberer$vmethods	soot_util_Numberer;
	_jc_soot_util_StringNumberer$vmethods	soot_util_StringNumberer;
};

// Vtype
struct _jc_soot_util_StringNumberer$vtype {
	_jc_type			type;
	_jc_soot_util_StringNumberer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_StringNumberer$sub_refs {
	struct _jc_java_util_HashMap$object	*stringToNumbered;
};

// Reference instance fields (object)
struct _jc_soot_util_StringNumberer$refs {
    _jc_soot_util_StringNumberer$sub_refs	soot_util_StringNumberer;
    _jc_soot_util_Numberer$sub_refs	soot_util_Numberer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_StringNumberer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_StringNumberer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Numberer$sub_nonrefs	soot_util_Numberer;
    _jc_soot_util_StringNumberer$sub_nonrefs	soot_util_StringNumberer;
};

// Object instance structure
struct _jc_soot_util_StringNumberer$object {
	_jc_soot_util_StringNumberer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_StringNumberer$vtype	*vtype;
	_jc_soot_util_StringNumberer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_StringNumberer$vtype _jc_soot_util_StringNumberer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_StringNumberer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_StringNumberer$class_object;

#endif	/* _JC_soot_util_StringNumberer_H_ */
